@@ -1,9 +1,7 @@
-from .jsonrenderer import JSONRenderer
 from .pngrenderer import PNGRenderer
 from .svgrenderer import SVGRenderer
 
 __all__ = [
-    'JSONRenderer',
     'PNGRenderer',
     'SVGRenderer'
 ]
